# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class DemandForecastApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def forecast_demand_daily_evolution_get(self, forecast_date, **kwargs):  # noqa: E501
        """Evolution of the fourteen-day demand forecast over time (NDFD, TSDFD)  # noqa: E501

        This endpoint provides the evolution of all daily demand forecasts over time for a given forecast date.                Date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_daily_evolution_get(forecast_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date forecast_date: The forecast date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_daily_evolution_get_with_http_info(forecast_date, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_daily_evolution_get_with_http_info(forecast_date, **kwargs)  # noqa: E501
            return data

    def forecast_demand_daily_evolution_get_with_http_info(self, forecast_date, **kwargs):  # noqa: E501
        """Evolution of the fourteen-day demand forecast over time (NDFD, TSDFD)  # noqa: E501

        This endpoint provides the evolution of all daily demand forecasts over time for a given forecast date.                Date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_daily_evolution_get_with_http_info(forecast_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date forecast_date: The forecast date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_date', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_daily_evolution_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'forecast_date' is set
        if ('forecast_date' not in params or
                params['forecast_date'] is None):
            raise ValueError("Missing the required parameter `forecast_date` when calling `forecast_demand_daily_evolution_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'forecast_date' in params:
            query_params.append(('forecastDate', params['forecast_date']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/daily/evolution', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_daily_get(self, **kwargs):  # noqa: E501
        """Fourteen day demand forecast (NDFD, TSDFD)  # noqa: E501

        Retrieve latest 14-day forecast demand data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_daily_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_daily_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_daily_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_demand_daily_get_with_http_info(self, **kwargs):  # noqa: E501
        """Fourteen day demand forecast (NDFD, TSDFD)  # noqa: E501

        Retrieve latest 14-day forecast demand data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_daily_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_daily_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/daily', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_daily_history_get(self, publish_time, **kwargs):  # noqa: E501
        """History of the fourteen-day demand forecast (NDFD, TSDFD)  # noqa: E501

        Retrieve historical daily forecast demand data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_daily_history_get(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_daily_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_daily_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
            return data

    def forecast_demand_daily_history_get_with_http_info(self, publish_time, **kwargs):  # noqa: E501
        """History of the fourteen-day demand forecast (NDFD, TSDFD)  # noqa: E501

        Retrieve historical daily forecast demand data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_daily_history_get_with_http_info(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_time', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_daily_history_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_time' is set
        if ('publish_time' not in params or
                params['publish_time'] is None):
            raise ValueError("Missing the required parameter `publish_time` when calling `forecast_demand_daily_history_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'publish_time' in params:
            query_params.append(('publishTime', params['publish_time']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/daily/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDaily',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_day_ahead_earliest_get(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the earliest forecasted demand (NDF, TSDF)  # noqa: E501

        This endpoint allows for retrieving earliest day-ahead demand forecast data from National Grid ESO.  Results are filtered by settlement time, and only the earliest published forecast for each settlement period is shown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_earliest_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_day_ahead_earliest_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_day_ahead_earliest_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_demand_day_ahead_earliest_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the earliest forecasted demand (NDF, TSDF)  # noqa: E501

        This endpoint allows for retrieving earliest day-ahead demand forecast data from National Grid ESO.  Results are filtered by settlement time, and only the earliest published forecast for each settlement period is shown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_earliest_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'boundary', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_day_ahead_earliest_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_demand_day_ahead_earliest_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_demand_day_ahead_earliest_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'boundary' in params:
            query_params.append(('boundary', params['boundary']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/day-ahead/earliest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_day_ahead_earliest_stream_get(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the earliest forecasted demand (NDF, TSDF) stream  # noqa: E501

        This endpoint allows for retrieving a stream of earliest day-ahead demand forecast data from National Grid ESO.  Results are filtered by settlement time, and only the earliest published forecast for each settlement period is shown.  This endpoint has an optimised JSON payload and aimed at frequent request for the day-ahead demand forecast data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_earliest_stream_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :return: list[InsightsApiModelsServiceDayAheadDemandForecastRow]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_day_ahead_earliest_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_day_ahead_earliest_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_demand_day_ahead_earliest_stream_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the earliest forecasted demand (NDF, TSDF) stream  # noqa: E501

        This endpoint allows for retrieving a stream of earliest day-ahead demand forecast data from National Grid ESO.  Results are filtered by settlement time, and only the earliest published forecast for each settlement period is shown.  This endpoint has an optimised JSON payload and aimed at frequent request for the day-ahead demand forecast data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_earliest_stream_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :return: list[InsightsApiModelsServiceDayAheadDemandForecastRow]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'boundary']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_day_ahead_earliest_stream_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_demand_day_ahead_earliest_stream_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_demand_day_ahead_earliest_stream_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'boundary' in params:
            query_params.append(('boundary', params['boundary']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/day-ahead/earliest/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InsightsApiModelsServiceDayAheadDemandForecastRow]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_day_ahead_evolution_get(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Evolution of the day-ahead demand forecast over time (NDF, TSDF)  # noqa: E501

        This endpoint provides the day and day ahead demand forecast and are categorized as National Demand Forecast (NDF) and Transmission System Demand Forecast (TSDF);  the forecast values are derived by NGESO and is based on historically metered generation output for Great Britain.  The data is updated every 30 minutes and within 15 minutes of the end of the effective Settlement Period.  NDF takes into account transmission losses but but does not include station transformer load, pumped storage demand or Interconnector demand;  the data is reported only at national level; and TSDF which takes into account transmission losses , station transformer load, pumped storage demand and interconnector demand.  The data is reported both at national and boundary (system zones) level. Boundary data only available for Transmission System Demand Forecast (TSDF).                Date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_evolution_get(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param list[int] settlement_period: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_day_ahead_evolution_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_day_ahead_evolution_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
            return data

    def forecast_demand_day_ahead_evolution_get_with_http_info(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Evolution of the day-ahead demand forecast over time (NDF, TSDF)  # noqa: E501

        This endpoint provides the day and day ahead demand forecast and are categorized as National Demand Forecast (NDF) and Transmission System Demand Forecast (TSDF);  the forecast values are derived by NGESO and is based on historically metered generation output for Great Britain.  The data is updated every 30 minutes and within 15 minutes of the end of the effective Settlement Period.  NDF takes into account transmission losses but but does not include station transformer load, pumped storage demand or Interconnector demand;  the data is reported only at national level; and TSDF which takes into account transmission losses , station transformer load, pumped storage demand and interconnector demand.  The data is reported both at national and boundary (system zones) level. Boundary data only available for Transmission System Demand Forecast (TSDF).                Date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_evolution_get_with_http_info(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param list[int] settlement_period: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'settlement_period', 'boundary', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_day_ahead_evolution_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `forecast_demand_day_ahead_evolution_get`")  # noqa: E501
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `forecast_demand_day_ahead_evolution_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'settlement_date' in params:
            query_params.append(('settlementDate', params['settlement_date']))  # noqa: E501
        if 'settlement_period' in params:
            query_params.append(('settlementPeriod', params['settlement_period']))  # noqa: E501
            collection_formats['settlementPeriod'] = 'multi'  # noqa: E501
        if 'boundary' in params:
            query_params.append(('boundary', params['boundary']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/day-ahead/evolution', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_day_ahead_get(self, **kwargs):  # noqa: E501
        """Day-ahead demand forecast (NDF, TSDF)  # noqa: E501

        This endpoint provides the day and day ahead demand forecast and are categorized as National Demand Forecast (NDF) and Transmission System Demand Forecast (TSDF);  the forecast values are derived by NGESO and is based on historically metered generation output for Great Britain.  The data is updated every 30 minutes and within 15 minutes of the end of the effective Settlement Period.  NDF takes into account transmission losses but but does not include station transformer load, pumped storage demand or Interconnector demand;  the data is reported only at national level; and TSDF which takes into account transmission losses , station transformer load, pumped storage demand and interconnector demand.  The data is reported both at national and boundary (system zones) level. Boundary data only available for Transmission System Demand Forecast (TSDF).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_day_ahead_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_day_ahead_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_demand_day_ahead_get_with_http_info(self, **kwargs):  # noqa: E501
        """Day-ahead demand forecast (NDF, TSDF)  # noqa: E501

        This endpoint provides the day and day ahead demand forecast and are categorized as National Demand Forecast (NDF) and Transmission System Demand Forecast (TSDF);  the forecast values are derived by NGESO and is based on historically metered generation output for Great Britain.  The data is updated every 30 minutes and within 15 minutes of the end of the effective Settlement Period.  NDF takes into account transmission losses but but does not include station transformer load, pumped storage demand or Interconnector demand;  the data is reported only at national level; and TSDF which takes into account transmission losses , station transformer load, pumped storage demand and interconnector demand.  The data is reported both at national and boundary (system zones) level. Boundary data only available for Transmission System Demand Forecast (TSDF).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['boundary', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_day_ahead_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'boundary' in params:
            query_params.append(('boundary', params['boundary']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/day-ahead', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_day_ahead_history_get(self, publish_time, **kwargs):  # noqa: E501
        """History of the day-ahead demand forecast (NDF, TSDF)  # noqa: E501

        This endpoint provides the day and day ahead demand forecast and are categorized as National Demand Forecast (NDF) and Transmission System Demand Forecast (TSDF);  the forecast values are derived by NGESO and is based on historically metered generation output for Great Britain.  The data is updated every 30 minutes and within 15 minutes of the end of the effective Settlement Period.  NDF takes into account transmission losses but but does not include station transformer load, pumped storage demand or Interconnector demand;  the data is reported only at national level; and TSDF which takes into account transmission losses , station transformer load, pumped storage demand and interconnector demand.  The data is reported both at national and boundary (system zones) level. Boundary data only available for Transmission System Demand Forecast (TSDF).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_history_get(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_day_ahead_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_day_ahead_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
            return data

    def forecast_demand_day_ahead_history_get_with_http_info(self, publish_time, **kwargs):  # noqa: E501
        """History of the day-ahead demand forecast (NDF, TSDF)  # noqa: E501

        This endpoint provides the day and day ahead demand forecast and are categorized as National Demand Forecast (NDF) and Transmission System Demand Forecast (TSDF);  the forecast values are derived by NGESO and is based on historically metered generation output for Great Britain.  The data is updated every 30 minutes and within 15 minutes of the end of the effective Settlement Period.  NDF takes into account transmission losses but but does not include station transformer load, pumped storage demand or Interconnector demand;  the data is reported only at national level; and TSDF which takes into account transmission losses , station transformer load, pumped storage demand and interconnector demand.  The data is reported both at national and boundary (system zones) level. Boundary data only available for Transmission System Demand Forecast (TSDF).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_history_get_with_http_info(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_time', 'boundary', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_day_ahead_history_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_time' is set
        if ('publish_time' not in params or
                params['publish_time'] is None):
            raise ValueError("Missing the required parameter `publish_time` when calling `forecast_demand_day_ahead_history_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'publish_time' in params:
            query_params.append(('publishTime', params['publish_time']))  # noqa: E501
        if 'boundary' in params:
            query_params.append(('boundary', params['boundary']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/day-ahead/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_day_ahead_latest_get(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the latest forecasted demand (NDF, TSDF)  # noqa: E501

        This endpoint allows for retrieving latest day-ahead demand forecast data from National Grid ESO.  Results are filtered by settlement time, and only the latest published forecast for each settlement period is shown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_latest_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_day_ahead_latest_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_day_ahead_latest_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_demand_day_ahead_latest_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the latest forecasted demand (NDF, TSDF)  # noqa: E501

        This endpoint allows for retrieving latest day-ahead demand forecast data from National Grid ESO.  Results are filtered by settlement time, and only the latest published forecast for each settlement period is shown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_latest_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'boundary', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_day_ahead_latest_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_demand_day_ahead_latest_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_demand_day_ahead_latest_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'boundary' in params:
            query_params.append(('boundary', params['boundary']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/day-ahead/latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastDayAhead',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_day_ahead_latest_stream_get(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the latest forecasted demand (NDF, TSDF) stream  # noqa: E501

        This endpoint allows for retrieving a stream of latest day-ahead demand forecast data from National Grid ESO.  Results are filtered by settlement time, and only the latest published forecast for each settlement period is shown.  This endpoint has an optimised JSON payload and aimed at frequent request for the day-ahead demand forecast data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_latest_stream_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :return: list[InsightsApiModelsServiceDayAheadDemandForecastRow]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_day_ahead_latest_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_day_ahead_latest_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_demand_day_ahead_latest_stream_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Historic view of the latest forecasted demand (NDF, TSDF) stream  # noqa: E501

        This endpoint allows for retrieving a stream of latest day-ahead demand forecast data from National Grid ESO.  Results are filtered by settlement time, and only the latest published forecast for each settlement period is shown.  This endpoint has an optimised JSON payload and aimed at frequent request for the day-ahead demand forecast data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_latest_stream_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str boundary: Omitting this will return only national data. Specifying boundary=zonal will return only zonal data.
        :return: list[InsightsApiModelsServiceDayAheadDemandForecastRow]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'boundary']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_day_ahead_latest_stream_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_demand_day_ahead_latest_stream_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_demand_day_ahead_latest_stream_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'boundary' in params:
            query_params.append(('boundary', params['boundary']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/day-ahead/latest/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InsightsApiModelsServiceDayAheadDemandForecastRow]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_day_ahead_peak_get(self, **kwargs):  # noqa: E501
        """Peak forecasted demand per day (TSDF)  # noqa: E501

        This endpoint allows for retrieving the peak demand that is forecast for each day from National Grid ESO.  Results are filtered by a range of Date parameters.  Results default to yesterday, today and tomorrow if no parameters are supplied.                Date parameters must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_peak_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str boundary:
        :param date _from: The start of the requested date range.
        :param date to: The end of the requested date range.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastPeak
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_day_ahead_peak_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_day_ahead_peak_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_demand_day_ahead_peak_get_with_http_info(self, **kwargs):  # noqa: E501
        """Peak forecasted demand per day (TSDF)  # noqa: E501

        This endpoint allows for retrieving the peak demand that is forecast for each day from National Grid ESO.  Results are filtered by a range of Date parameters.  Results default to yesterday, today and tomorrow if no parameters are supplied.                Date parameters must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_day_ahead_peak_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str boundary:
        :param date _from: The start of the requested date range.
        :param date to: The end of the requested date range.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastPeak
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['boundary', '_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_day_ahead_peak_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'boundary' in params:
            query_params.append(('boundary', params['boundary']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/day-ahead/peak', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastPeak',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_total_day_ahead_get(self, _from, to, **kwargs):  # noqa: E501
        """Day-ahead total load forecast (DATL/B0620)  # noqa: E501

        This endpoint provides day-ahead total load forecast per bidding zone data.  It can be filtered by settlement period dates.                This API endpoint has a maximum range of 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_total_day_ahead_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param int settlement_period_from:
        :param int settlement_period_to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadTotalLoadPerBiddingZone
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_total_day_ahead_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_total_day_ahead_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_demand_total_day_ahead_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Day-ahead total load forecast (DATL/B0620)  # noqa: E501

        This endpoint provides day-ahead total load forecast per bidding zone data.  It can be filtered by settlement period dates.                This API endpoint has a maximum range of 7 days.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_total_day_ahead_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param int settlement_period_from:
        :param int settlement_period_to:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadTotalLoadPerBiddingZone
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'settlement_period_from', 'settlement_period_to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_total_day_ahead_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_demand_total_day_ahead_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_demand_total_day_ahead_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'settlement_period_from' in params:
            query_params.append(('settlementPeriodFrom', params['settlement_period_from']))  # noqa: E501
        if 'settlement_period_to' in params:
            query_params.append(('settlementPeriodTo', params['settlement_period_to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/total/day-ahead', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyDayAheadTotalLoadPerBiddingZone',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_total_week_ahead_get(self, _from, to, **kwargs):  # noqa: E501
        """Week-ahead total load forecast (WATL/B0630)  # noqa: E501

        This endpoint returns week-ahead total load forecast per bidding zone data with the minimum possible  and maximum available total loads in MW values, filtered by forecast week.                For a given forecast date, if more than one forecast has been published, only the most recent forecast  is returned.                This API endpoint has a maximum range of 367 days.                Date parameters must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_total_week_ahead_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date _from: The earliest forecast date to include. (required)
        :param date to: The latest forecast date to include. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyWeekAheadTotalLoadPerBiddingZone
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_total_week_ahead_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_total_week_ahead_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def forecast_demand_total_week_ahead_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Week-ahead total load forecast (WATL/B0630)  # noqa: E501

        This endpoint returns week-ahead total load forecast per bidding zone data with the minimum possible  and maximum available total loads in MW values, filtered by forecast week.                For a given forecast date, if more than one forecast has been published, only the most recent forecast  is returned.                This API endpoint has a maximum range of 367 days.                Date parameters must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_total_week_ahead_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date _from: The earliest forecast date to include. (required)
        :param date to: The latest forecast date to include. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyWeekAheadTotalLoadPerBiddingZone
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_total_week_ahead_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `forecast_demand_total_week_ahead_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `forecast_demand_total_week_ahead_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/total/week-ahead', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyWeekAheadTotalLoadPerBiddingZone',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_total_week_ahead_latest_get(self, **kwargs):  # noqa: E501
        """Latest week-ahead total load forecast (WATL/B0630)  # noqa: E501

        This endpoint returns the most recently published WATL / B0630 forecast.                This forecast is the week-ahead total load forecast per bidding zone data,  with minimum possible and maximum available total loads in MW values.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_total_week_ahead_latest_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyWeekAheadTotalLoadPerBiddingZone
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_total_week_ahead_latest_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_total_week_ahead_latest_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_demand_total_week_ahead_latest_get_with_http_info(self, **kwargs):  # noqa: E501
        """Latest week-ahead total load forecast (WATL/B0630)  # noqa: E501

        This endpoint returns the most recently published WATL / B0630 forecast.                This forecast is the week-ahead total load forecast per bidding zone data,  with minimum possible and maximum available total loads in MW values.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_total_week_ahead_latest_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyWeekAheadTotalLoadPerBiddingZone
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_total_week_ahead_latest_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/total/week-ahead/latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyWeekAheadTotalLoadPerBiddingZone',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_weekly_evolution_get(self, forecast_year, forecast_week, **kwargs):  # noqa: E501
        """Evolution of the one-year demand forecast over time  (NDFW, TSDFW)  # noqa: E501

        This endpoint provides all weekly demand forecasts over time for a given forecast Year and Week  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_weekly_evolution_get(forecast_year, forecast_week, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int forecast_year: (required)
        :param int forecast_week: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_weekly_evolution_get_with_http_info(forecast_year, forecast_week, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_weekly_evolution_get_with_http_info(forecast_year, forecast_week, **kwargs)  # noqa: E501
            return data

    def forecast_demand_weekly_evolution_get_with_http_info(self, forecast_year, forecast_week, **kwargs):  # noqa: E501
        """Evolution of the one-year demand forecast over time  (NDFW, TSDFW)  # noqa: E501

        This endpoint provides all weekly demand forecasts over time for a given forecast Year and Week  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_weekly_evolution_get_with_http_info(forecast_year, forecast_week, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int forecast_year: (required)
        :param int forecast_week: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_year', 'forecast_week', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_weekly_evolution_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'forecast_year' is set
        if ('forecast_year' not in params or
                params['forecast_year'] is None):
            raise ValueError("Missing the required parameter `forecast_year` when calling `forecast_demand_weekly_evolution_get`")  # noqa: E501
        # verify the required parameter 'forecast_week' is set
        if ('forecast_week' not in params or
                params['forecast_week'] is None):
            raise ValueError("Missing the required parameter `forecast_week` when calling `forecast_demand_weekly_evolution_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'forecast_year' in params:
            query_params.append(('forecastYear', params['forecast_year']))  # noqa: E501
        if 'forecast_week' in params:
            query_params.append(('forecastWeek', params['forecast_week']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/weekly/evolution', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_weekly_get(self, **kwargs):  # noqa: E501
        """One-year demand forecast (NDFW, TSDFW)  # noqa: E501

        This endpoint provides the latest weekly forecast demand data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_weekly_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_weekly_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_weekly_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_demand_weekly_get_with_http_info(self, **kwargs):  # noqa: E501
        """One-year demand forecast (NDFW, TSDFW)  # noqa: E501

        This endpoint provides the latest weekly forecast demand data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_weekly_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_weekly_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/weekly', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_demand_weekly_history_get(self, publish_time, **kwargs):  # noqa: E501
        """History of the one-year demand forecast (NDFW, TSDFW)  # noqa: E501

        Retrieve historical weekly forecast demand data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_weekly_history_get(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_demand_weekly_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_demand_weekly_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
            return data

    def forecast_demand_weekly_history_get_with_http_info(self, publish_time, **kwargs):  # noqa: E501
        """History of the one-year demand forecast (NDFW, TSDFW)  # noqa: E501

        Retrieve historical weekly forecast demand data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_demand_weekly_history_get_with_http_info(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_time', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_demand_weekly_history_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_time' is set
        if ('publish_time' not in params or
                params['publish_time'] is None):
            raise ValueError("Missing the required parameter `publish_time` when calling `forecast_demand_weekly_history_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'publish_time' in params:
            query_params.append(('publishTime', params['publish_time']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/demand/weekly/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesDemandForecastDemandForecastWeekly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'negative1': 'float',
        'positive1': 'float',
        'negative2': 'float',
        'positive2': 'float',
        'negative3': 'float',
        'positive3': 'float',
        'negative4': 'float',
        'positive4': 'float',
        'negative5': 'float',
        'positive5': 'float',
        'negative6': 'float',
        'positive6': 'float'
    }

    attribute_map = {
        'negative1': 'negative1',
        'positive1': 'positive1',
        'negative2': 'negative2',
        'positive2': 'positive2',
        'negative3': 'negative3',
        'positive3': 'positive3',
        'negative4': 'negative4',
        'positive4': 'positive4',
        'negative5': 'negative5',
        'positive5': 'positive5',
        'negative6': 'negative6',
        'positive6': 'positive6'
    }

    def __init__(self, negative1=None, positive1=None, negative2=None, positive2=None, negative3=None, positive3=None, negative4=None, positive4=None, negative5=None, positive5=None, negative6=None, positive6=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs - a model defined in Swagger"""  # noqa: E501
        self._negative1 = None
        self._positive1 = None
        self._negative2 = None
        self._positive2 = None
        self._negative3 = None
        self._positive3 = None
        self._negative4 = None
        self._positive4 = None
        self._negative5 = None
        self._positive5 = None
        self._negative6 = None
        self._positive6 = None
        self.discriminator = None
        if negative1 is not None:
            self.negative1 = negative1
        if positive1 is not None:
            self.positive1 = positive1
        if negative2 is not None:
            self.negative2 = negative2
        if positive2 is not None:
            self.positive2 = positive2
        if negative3 is not None:
            self.negative3 = negative3
        if positive3 is not None:
            self.positive3 = positive3
        if negative4 is not None:
            self.negative4 = negative4
        if positive4 is not None:
            self.positive4 = positive4
        if negative5 is not None:
            self.negative5 = negative5
        if positive5 is not None:
            self.positive5 = positive5
        if negative6 is not None:
            self.negative6 = negative6
        if positive6 is not None:
            self.positive6 = positive6

    @property
    def negative1(self):
        """Gets the negative1 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The negative1 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._negative1

    @negative1.setter
    def negative1(self, negative1):
        """Sets the negative1 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param negative1: The negative1 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._negative1 = negative1

    @property
    def positive1(self):
        """Gets the positive1 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The positive1 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._positive1

    @positive1.setter
    def positive1(self, positive1):
        """Sets the positive1 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param positive1: The positive1 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._positive1 = positive1

    @property
    def negative2(self):
        """Gets the negative2 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The negative2 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._negative2

    @negative2.setter
    def negative2(self, negative2):
        """Sets the negative2 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param negative2: The negative2 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._negative2 = negative2

    @property
    def positive2(self):
        """Gets the positive2 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The positive2 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._positive2

    @positive2.setter
    def positive2(self, positive2):
        """Sets the positive2 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param positive2: The positive2 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._positive2 = positive2

    @property
    def negative3(self):
        """Gets the negative3 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The negative3 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._negative3

    @negative3.setter
    def negative3(self, negative3):
        """Sets the negative3 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param negative3: The negative3 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._negative3 = negative3

    @property
    def positive3(self):
        """Gets the positive3 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The positive3 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._positive3

    @positive3.setter
    def positive3(self, positive3):
        """Sets the positive3 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param positive3: The positive3 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._positive3 = positive3

    @property
    def negative4(self):
        """Gets the negative4 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The negative4 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._negative4

    @negative4.setter
    def negative4(self, negative4):
        """Sets the negative4 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param negative4: The negative4 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._negative4 = negative4

    @property
    def positive4(self):
        """Gets the positive4 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The positive4 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._positive4

    @positive4.setter
    def positive4(self, positive4):
        """Sets the positive4 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param positive4: The positive4 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._positive4 = positive4

    @property
    def negative5(self):
        """Gets the negative5 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The negative5 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._negative5

    @negative5.setter
    def negative5(self, negative5):
        """Sets the negative5 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param negative5: The negative5 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._negative5 = negative5

    @property
    def positive5(self):
        """Gets the positive5 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The positive5 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._positive5

    @positive5.setter
    def positive5(self, positive5):
        """Sets the positive5 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param positive5: The positive5 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._positive5 = positive5

    @property
    def negative6(self):
        """Gets the negative6 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The negative6 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._negative6

    @negative6.setter
    def negative6(self, negative6):
        """Sets the negative6 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param negative6: The negative6 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._negative6 = negative6

    @property
    def positive6(self):
        """Gets the positive6 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501


        :return: The positive6 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :rtype: float
        """
        return self._positive6

    @positive6.setter
    def positive6(self, positive6):
        """Sets the positive6 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.


        :param positive6: The positive6 of this InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs.  # noqa: E501
        :type: float
        """

        self._positive6 = positive6

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingSettlementDerivedDataBidOfferPairs):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'serial_number': 'str',
        'file_creation_time': 'datetime',
        'trading_unit_type': 'str',
        'trading_unit_name': 'str',
        'settlement_date': 'date',
        'settlement_period': 'int',
        'settlement_run_type': 'str',
        'start_time': 'datetime',
        'delivery_mode': 'str',
        'import_volume': 'float',
        'export_volume': 'float',
        'net_volume': 'float'
    }

    attribute_map = {
        'dataset': 'dataset',
        'serial_number': 'serialNumber',
        'file_creation_time': 'fileCreationTime',
        'trading_unit_type': 'tradingUnitType',
        'trading_unit_name': 'tradingUnitName',
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'settlement_run_type': 'settlementRunType',
        'start_time': 'startTime',
        'delivery_mode': 'deliveryMode',
        'import_volume': 'importVolume',
        'export_volume': 'exportVolume',
        'net_volume': 'netVolume'
    }

    def __init__(self, dataset=None, serial_number=None, file_creation_time=None, trading_unit_type=None, trading_unit_name=None, settlement_date=None, settlement_period=None, settlement_run_type=None, start_time=None, delivery_mode=None, import_volume=None, export_volume=None, net_volume=None):  # noqa: E501
        """InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._serial_number = None
        self._file_creation_time = None
        self._trading_unit_type = None
        self._trading_unit_name = None
        self._settlement_date = None
        self._settlement_period = None
        self._settlement_run_type = None
        self._start_time = None
        self._delivery_mode = None
        self._import_volume = None
        self._export_volume = None
        self._net_volume = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if serial_number is not None:
            self.serial_number = serial_number
        if file_creation_time is not None:
            self.file_creation_time = file_creation_time
        if trading_unit_type is not None:
            self.trading_unit_type = trading_unit_type
        if trading_unit_name is not None:
            self.trading_unit_name = trading_unit_name
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if settlement_run_type is not None:
            self.settlement_run_type = settlement_run_type
        if start_time is not None:
            self.start_time = start_time
        if delivery_mode is not None:
            self.delivery_mode = delivery_mode
        if import_volume is not None:
            self.import_volume = import_volume
        if export_volume is not None:
            self.export_volume = export_volume
        if net_volume is not None:
            self.net_volume = net_volume

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param dataset: The dataset of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def serial_number(self):
        """Gets the serial_number of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The serial_number of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param serial_number: The serial_number of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    @property
    def file_creation_time(self):
        """Gets the file_creation_time of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The file_creation_time of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._file_creation_time

    @file_creation_time.setter
    def file_creation_time(self, file_creation_time):
        """Sets the file_creation_time of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param file_creation_time: The file_creation_time of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._file_creation_time = file_creation_time

    @property
    def trading_unit_type(self):
        """Gets the trading_unit_type of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The trading_unit_type of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._trading_unit_type

    @trading_unit_type.setter
    def trading_unit_type(self, trading_unit_type):
        """Sets the trading_unit_type of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param trading_unit_type: The trading_unit_type of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: str
        """

        self._trading_unit_type = trading_unit_type

    @property
    def trading_unit_name(self):
        """Gets the trading_unit_name of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The trading_unit_name of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._trading_unit_name

    @trading_unit_name.setter
    def trading_unit_name(self, trading_unit_name):
        """Sets the trading_unit_name of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param trading_unit_name: The trading_unit_name of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: str
        """

        self._trading_unit_name = trading_unit_name

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def settlement_run_type(self):
        """Gets the settlement_run_type of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The settlement_run_type of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._settlement_run_type

    @settlement_run_type.setter
    def settlement_run_type(self, settlement_run_type):
        """Sets the settlement_run_type of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param settlement_run_type: The settlement_run_type of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: str
        """

        self._settlement_run_type = settlement_run_type

    @property
    def start_time(self):
        """Gets the start_time of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The start_time of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param start_time: The start_time of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def delivery_mode(self):
        """Gets the delivery_mode of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The delivery_mode of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: str
        """
        return self._delivery_mode

    @delivery_mode.setter
    def delivery_mode(self, delivery_mode):
        """Sets the delivery_mode of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param delivery_mode: The delivery_mode of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: str
        """

        self._delivery_mode = delivery_mode

    @property
    def import_volume(self):
        """Gets the import_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The import_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: float
        """
        return self._import_volume

    @import_volume.setter
    def import_volume(self, import_volume):
        """Sets the import_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param import_volume: The import_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: float
        """

        self._import_volume = import_volume

    @property
    def export_volume(self):
        """Gets the export_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The export_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: float
        """
        return self._export_volume

    @export_volume.setter
    def export_volume(self, export_volume):
        """Sets the export_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param export_volume: The export_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: float
        """

        self._export_volume = export_volume

    @property
    def net_volume(self):
        """Gets the net_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501


        :return: The net_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :rtype: float
        """
        return self._net_volume

    @net_volume.setter
    def net_volume(self, net_volume):
        """Sets the net_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.


        :param net_volume: The net_volume of this InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow.  # noqa: E501
        :type: float
        """

        self._net_volume = net_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesMiscDatasetRowsTudmDatasetRow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'settlement_date': 'date',
        'settlement_period': 'int',
        'indicated_imbalance': 'int',
        'offer_volume': 'float',
        'bid_volume': 'float',
        'total_accepted_offer_volume': 'float',
        'total_accepted_bid_volume': 'float',
        'priced_accepted_offers_volume': 'float',
        'priced_accepted_bids_volume': 'float'
    }

    attribute_map = {
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'indicated_imbalance': 'indicatedImbalance',
        'offer_volume': 'offerVolume',
        'bid_volume': 'bidVolume',
        'total_accepted_offer_volume': 'totalAcceptedOfferVolume',
        'total_accepted_bid_volume': 'totalAcceptedBidVolume',
        'priced_accepted_offers_volume': 'pricedAcceptedOffersVolume',
        'priced_accepted_bids_volume': 'pricedAcceptedBidsVolume'
    }

    def __init__(self, settlement_date=None, settlement_period=None, indicated_imbalance=None, offer_volume=None, bid_volume=None, total_accepted_offer_volume=None, total_accepted_bid_volume=None, priced_accepted_offers_volume=None, priced_accepted_bids_volume=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse - a model defined in Swagger"""  # noqa: E501
        self._settlement_date = None
        self._settlement_period = None
        self._indicated_imbalance = None
        self._offer_volume = None
        self._bid_volume = None
        self._total_accepted_offer_volume = None
        self._total_accepted_bid_volume = None
        self._priced_accepted_offers_volume = None
        self._priced_accepted_bids_volume = None
        self.discriminator = None
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if indicated_imbalance is not None:
            self.indicated_imbalance = indicated_imbalance
        if offer_volume is not None:
            self.offer_volume = offer_volume
        if bid_volume is not None:
            self.bid_volume = bid_volume
        if total_accepted_offer_volume is not None:
            self.total_accepted_offer_volume = total_accepted_offer_volume
        if total_accepted_bid_volume is not None:
            self.total_accepted_bid_volume = total_accepted_bid_volume
        if priced_accepted_offers_volume is not None:
            self.priced_accepted_offers_volume = priced_accepted_offers_volume
        if priced_accepted_bids_volume is not None:
            self.priced_accepted_bids_volume = priced_accepted_bids_volume

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def indicated_imbalance(self):
        """Gets the indicated_imbalance of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501


        :return: The indicated_imbalance of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :rtype: int
        """
        return self._indicated_imbalance

    @indicated_imbalance.setter
    def indicated_imbalance(self, indicated_imbalance):
        """Sets the indicated_imbalance of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.


        :param indicated_imbalance: The indicated_imbalance of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :type: int
        """

        self._indicated_imbalance = indicated_imbalance

    @property
    def offer_volume(self):
        """Gets the offer_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501


        :return: The offer_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :rtype: float
        """
        return self._offer_volume

    @offer_volume.setter
    def offer_volume(self, offer_volume):
        """Sets the offer_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.


        :param offer_volume: The offer_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :type: float
        """

        self._offer_volume = offer_volume

    @property
    def bid_volume(self):
        """Gets the bid_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501


        :return: The bid_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :rtype: float
        """
        return self._bid_volume

    @bid_volume.setter
    def bid_volume(self, bid_volume):
        """Sets the bid_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.


        :param bid_volume: The bid_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :type: float
        """

        self._bid_volume = bid_volume

    @property
    def total_accepted_offer_volume(self):
        """Gets the total_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501


        :return: The total_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_accepted_offer_volume

    @total_accepted_offer_volume.setter
    def total_accepted_offer_volume(self, total_accepted_offer_volume):
        """Sets the total_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.


        :param total_accepted_offer_volume: The total_accepted_offer_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :type: float
        """

        self._total_accepted_offer_volume = total_accepted_offer_volume

    @property
    def total_accepted_bid_volume(self):
        """Gets the total_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501


        :return: The total_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_accepted_bid_volume

    @total_accepted_bid_volume.setter
    def total_accepted_bid_volume(self, total_accepted_bid_volume):
        """Sets the total_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.


        :param total_accepted_bid_volume: The total_accepted_bid_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :type: float
        """

        self._total_accepted_bid_volume = total_accepted_bid_volume

    @property
    def priced_accepted_offers_volume(self):
        """Gets the priced_accepted_offers_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501


        :return: The priced_accepted_offers_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :rtype: float
        """
        return self._priced_accepted_offers_volume

    @priced_accepted_offers_volume.setter
    def priced_accepted_offers_volume(self, priced_accepted_offers_volume):
        """Sets the priced_accepted_offers_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.


        :param priced_accepted_offers_volume: The priced_accepted_offers_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :type: float
        """

        self._priced_accepted_offers_volume = priced_accepted_offers_volume

    @property
    def priced_accepted_bids_volume(self):
        """Gets the priced_accepted_bids_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501


        :return: The priced_accepted_bids_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :rtype: float
        """
        return self._priced_accepted_bids_volume

    @priced_accepted_bids_volume.setter
    def priced_accepted_bids_volume(self, priced_accepted_bids_volume):
        """Sets the priced_accepted_bids_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.


        :param priced_accepted_bids_volume: The priced_accepted_bids_volume of this InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse.  # noqa: E501
        :type: float
        """

        self._priced_accepted_bids_volume = priced_accepted_bids_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingSettlementMarketDepthResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'settlement_date': 'date',
        'settlement_period': 'int',
        'start_time': 'datetime',
        'created_date_time': 'datetime',
        'sequence_number': 'int',
        'id': 'str',
        'acceptance_id': 'int',
        'bid_offer_pair_id': 'int',
        'cadl_flag': 'bool',
        'so_flag': 'bool',
        'stor_provider_flag': 'bool',
        'repriced_indicator': 'bool',
        'reserve_scarcity_price': 'float',
        'original_price': 'float',
        'volume': 'float',
        'dmat_adjusted_volume': 'float',
        'arbitrage_adjusted_volume': 'float',
        'niv_adjusted_volume': 'float',
        'par_adjusted_volume': 'float',
        'final_price': 'float',
        'transmission_loss_multiplier': 'float',
        'tlm_adjusted_volume': 'float',
        'tlm_adjusted_cost': 'float'
    }

    attribute_map = {
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'start_time': 'startTime',
        'created_date_time': 'createdDateTime',
        'sequence_number': 'sequenceNumber',
        'id': 'id',
        'acceptance_id': 'acceptanceId',
        'bid_offer_pair_id': 'bidOfferPairId',
        'cadl_flag': 'cadlFlag',
        'so_flag': 'soFlag',
        'stor_provider_flag': 'storProviderFlag',
        'repriced_indicator': 'repricedIndicator',
        'reserve_scarcity_price': 'reserveScarcityPrice',
        'original_price': 'originalPrice',
        'volume': 'volume',
        'dmat_adjusted_volume': 'dmatAdjustedVolume',
        'arbitrage_adjusted_volume': 'arbitrageAdjustedVolume',
        'niv_adjusted_volume': 'nivAdjustedVolume',
        'par_adjusted_volume': 'parAdjustedVolume',
        'final_price': 'finalPrice',
        'transmission_loss_multiplier': 'transmissionLossMultiplier',
        'tlm_adjusted_volume': 'tlmAdjustedVolume',
        'tlm_adjusted_cost': 'tlmAdjustedCost'
    }

    def __init__(self, settlement_date=None, settlement_period=None, start_time=None, created_date_time=None, sequence_number=None, id=None, acceptance_id=None, bid_offer_pair_id=None, cadl_flag=None, so_flag=None, stor_provider_flag=None, repriced_indicator=None, reserve_scarcity_price=None, original_price=None, volume=None, dmat_adjusted_volume=None, arbitrage_adjusted_volume=None, niv_adjusted_volume=None, par_adjusted_volume=None, final_price=None, transmission_loss_multiplier=None, tlm_adjusted_volume=None, tlm_adjusted_cost=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse - a model defined in Swagger"""  # noqa: E501
        self._settlement_date = None
        self._settlement_period = None
        self._start_time = None
        self._created_date_time = None
        self._sequence_number = None
        self._id = None
        self._acceptance_id = None
        self._bid_offer_pair_id = None
        self._cadl_flag = None
        self._so_flag = None
        self._stor_provider_flag = None
        self._repriced_indicator = None
        self._reserve_scarcity_price = None
        self._original_price = None
        self._volume = None
        self._dmat_adjusted_volume = None
        self._arbitrage_adjusted_volume = None
        self._niv_adjusted_volume = None
        self._par_adjusted_volume = None
        self._final_price = None
        self._transmission_loss_multiplier = None
        self._tlm_adjusted_volume = None
        self._tlm_adjusted_cost = None
        self.discriminator = None
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if start_time is not None:
            self.start_time = start_time
        if created_date_time is not None:
            self.created_date_time = created_date_time
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if id is not None:
            self.id = id
        if acceptance_id is not None:
            self.acceptance_id = acceptance_id
        if bid_offer_pair_id is not None:
            self.bid_offer_pair_id = bid_offer_pair_id
        if cadl_flag is not None:
            self.cadl_flag = cadl_flag
        if so_flag is not None:
            self.so_flag = so_flag
        if stor_provider_flag is not None:
            self.stor_provider_flag = stor_provider_flag
        if repriced_indicator is not None:
            self.repriced_indicator = repriced_indicator
        if reserve_scarcity_price is not None:
            self.reserve_scarcity_price = reserve_scarcity_price
        if original_price is not None:
            self.original_price = original_price
        if volume is not None:
            self.volume = volume
        if dmat_adjusted_volume is not None:
            self.dmat_adjusted_volume = dmat_adjusted_volume
        if arbitrage_adjusted_volume is not None:
            self.arbitrage_adjusted_volume = arbitrage_adjusted_volume
        if niv_adjusted_volume is not None:
            self.niv_adjusted_volume = niv_adjusted_volume
        if par_adjusted_volume is not None:
            self.par_adjusted_volume = par_adjusted_volume
        if final_price is not None:
            self.final_price = final_price
        if transmission_loss_multiplier is not None:
            self.transmission_loss_multiplier = transmission_loss_multiplier
        if tlm_adjusted_volume is not None:
            self.tlm_adjusted_volume = tlm_adjusted_volume
        if tlm_adjusted_cost is not None:
            self.tlm_adjusted_cost = tlm_adjusted_cost

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def start_time(self):
        """Gets the start_time of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The start_time of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param start_time: The start_time of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def created_date_time(self):
        """Gets the created_date_time of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The created_date_time of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date_time

    @created_date_time.setter
    def created_date_time(self, created_date_time):
        """Sets the created_date_time of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param created_date_time: The created_date_time of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: datetime
        """

        self._created_date_time = created_date_time

    @property
    def sequence_number(self):
        """Gets the sequence_number of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The sequence_number of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param sequence_number: The sequence_number of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: int
        """

        self._sequence_number = sequence_number

    @property
    def id(self):
        """Gets the id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param id: The id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def acceptance_id(self):
        """Gets the acceptance_id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The acceptance_id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: int
        """
        return self._acceptance_id

    @acceptance_id.setter
    def acceptance_id(self, acceptance_id):
        """Sets the acceptance_id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param acceptance_id: The acceptance_id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: int
        """

        self._acceptance_id = acceptance_id

    @property
    def bid_offer_pair_id(self):
        """Gets the bid_offer_pair_id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The bid_offer_pair_id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: int
        """
        return self._bid_offer_pair_id

    @bid_offer_pair_id.setter
    def bid_offer_pair_id(self, bid_offer_pair_id):
        """Sets the bid_offer_pair_id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param bid_offer_pair_id: The bid_offer_pair_id of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: int
        """

        self._bid_offer_pair_id = bid_offer_pair_id

    @property
    def cadl_flag(self):
        """Gets the cadl_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The cadl_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: bool
        """
        return self._cadl_flag

    @cadl_flag.setter
    def cadl_flag(self, cadl_flag):
        """Sets the cadl_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param cadl_flag: The cadl_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: bool
        """

        self._cadl_flag = cadl_flag

    @property
    def so_flag(self):
        """Gets the so_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The so_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: bool
        """
        return self._so_flag

    @so_flag.setter
    def so_flag(self, so_flag):
        """Sets the so_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param so_flag: The so_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: bool
        """

        self._so_flag = so_flag

    @property
    def stor_provider_flag(self):
        """Gets the stor_provider_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The stor_provider_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: bool
        """
        return self._stor_provider_flag

    @stor_provider_flag.setter
    def stor_provider_flag(self, stor_provider_flag):
        """Sets the stor_provider_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param stor_provider_flag: The stor_provider_flag of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: bool
        """

        self._stor_provider_flag = stor_provider_flag

    @property
    def repriced_indicator(self):
        """Gets the repriced_indicator of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The repriced_indicator of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: bool
        """
        return self._repriced_indicator

    @repriced_indicator.setter
    def repriced_indicator(self, repriced_indicator):
        """Sets the repriced_indicator of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param repriced_indicator: The repriced_indicator of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: bool
        """

        self._repriced_indicator = repriced_indicator

    @property
    def reserve_scarcity_price(self):
        """Gets the reserve_scarcity_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The reserve_scarcity_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._reserve_scarcity_price

    @reserve_scarcity_price.setter
    def reserve_scarcity_price(self, reserve_scarcity_price):
        """Sets the reserve_scarcity_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param reserve_scarcity_price: The reserve_scarcity_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._reserve_scarcity_price = reserve_scarcity_price

    @property
    def original_price(self):
        """Gets the original_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The original_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._original_price

    @original_price.setter
    def original_price(self, original_price):
        """Sets the original_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param original_price: The original_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._original_price = original_price

    @property
    def volume(self):
        """Gets the volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param volume: The volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._volume = volume

    @property
    def dmat_adjusted_volume(self):
        """Gets the dmat_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The dmat_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._dmat_adjusted_volume

    @dmat_adjusted_volume.setter
    def dmat_adjusted_volume(self, dmat_adjusted_volume):
        """Sets the dmat_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param dmat_adjusted_volume: The dmat_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._dmat_adjusted_volume = dmat_adjusted_volume

    @property
    def arbitrage_adjusted_volume(self):
        """Gets the arbitrage_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The arbitrage_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._arbitrage_adjusted_volume

    @arbitrage_adjusted_volume.setter
    def arbitrage_adjusted_volume(self, arbitrage_adjusted_volume):
        """Sets the arbitrage_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param arbitrage_adjusted_volume: The arbitrage_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._arbitrage_adjusted_volume = arbitrage_adjusted_volume

    @property
    def niv_adjusted_volume(self):
        """Gets the niv_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The niv_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._niv_adjusted_volume

    @niv_adjusted_volume.setter
    def niv_adjusted_volume(self, niv_adjusted_volume):
        """Sets the niv_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param niv_adjusted_volume: The niv_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._niv_adjusted_volume = niv_adjusted_volume

    @property
    def par_adjusted_volume(self):
        """Gets the par_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The par_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._par_adjusted_volume

    @par_adjusted_volume.setter
    def par_adjusted_volume(self, par_adjusted_volume):
        """Sets the par_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param par_adjusted_volume: The par_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._par_adjusted_volume = par_adjusted_volume

    @property
    def final_price(self):
        """Gets the final_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The final_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._final_price

    @final_price.setter
    def final_price(self, final_price):
        """Sets the final_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param final_price: The final_price of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._final_price = final_price

    @property
    def transmission_loss_multiplier(self):
        """Gets the transmission_loss_multiplier of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The transmission_loss_multiplier of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._transmission_loss_multiplier

    @transmission_loss_multiplier.setter
    def transmission_loss_multiplier(self, transmission_loss_multiplier):
        """Sets the transmission_loss_multiplier of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param transmission_loss_multiplier: The transmission_loss_multiplier of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._transmission_loss_multiplier = transmission_loss_multiplier

    @property
    def tlm_adjusted_volume(self):
        """Gets the tlm_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The tlm_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._tlm_adjusted_volume

    @tlm_adjusted_volume.setter
    def tlm_adjusted_volume(self, tlm_adjusted_volume):
        """Sets the tlm_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param tlm_adjusted_volume: The tlm_adjusted_volume of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._tlm_adjusted_volume = tlm_adjusted_volume

    @property
    def tlm_adjusted_cost(self):
        """Gets the tlm_adjusted_cost of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501


        :return: The tlm_adjusted_cost of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :rtype: float
        """
        return self._tlm_adjusted_cost

    @tlm_adjusted_cost.setter
    def tlm_adjusted_cost(self, tlm_adjusted_cost):
        """Sets the tlm_adjusted_cost of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.


        :param tlm_adjusted_cost: The tlm_adjusted_cost of this InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse.  # noqa: E501
        :type: float
        """

        self._tlm_adjusted_cost = tlm_adjusted_cost

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingSettlementSettlementStackResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
